# fractalcam

Fractals with python and USB webcams!

## Install

Use git and conda to get the code and setup the environment:

```bash
git clone https://gitlab.com/ryanmcginger/fractalcam.git
cd fractalcam
conda env create -f environment.yaml
```

Then, just activate and run the script 'fracam.py':

```
conda activate fractalcam-env
fracam.py --help
```
